# coding: utf-8

# flake8: noqa

"""
    Torizon OTA

     This API is rate limited and will return the following headers for each API call.    - X-RateLimit-Limit - The total number of requests allowed within a time period   - X-RateLimit-Remaining - The total number of requests still allowed until the end of the rate limiting period   - X-RateLimit-Reset - The number of seconds until the limit is fully reset  In addition, if an API client is rate limited, it will receive a HTTP 420 response with the following header:     - Retry-After - The number of seconds to wait until this request is allowed  

    The version of the OpenAPI document: 2.0-Beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.0.3"

# Define package exports
__all__ = [
    "DeviceMetricsApi",
    "DevicesApi",
    "FleetsApi",
    "PackagesApi",
    "RemoteAccessApi",
    "UpdatesApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "BadRequestRepr",
    "ClientSignature",
    "ConflictRepr",
    "CreateFleet",
    "CreateLockboxRequest",
    "CreateSessionRequest",
    "CustomUpdateData",
    "DelegationInfo",
    "DetailedMetricQuery",
    "DeviceCreateReq",
    "DeviceId",
    "DeviceInfo",
    "DeviceInfoBasic",
    "DeviceInfoExtended",
    "DeviceNameRequest",
    "DeviceNotesRequest",
    "DevicePackages",
    "DeviceSession",
    "DeviceSort",
    "DeviceSortDirection",
    "DeviceStatus",
    "EcuInfoImage",
    "EcuInfoResponse",
    "EditPackage",
    "ErrorRepresentation",
    "ExternalPackage",
    "FileInfo",
    "Fleet",
    "FleetMetricsOutliersRequest",
    "FleetMetricsOutliersResponse",
    "FleetType",
    "Image",
    "InstalledPackage",
    "IpAddressRequest",
    "JsonSignedPayload",
    "KeyData",
    "LastSshSession",
    "MetricsResponse",
    "NetworkInfo",
    "NotFoundRepr",
    "Outlier",
    "OutlierAggregationMethod",
    "OutlierValues",
    "Package",
    "PaginationResultDeviceInfoBasic",
    "PaginationResultDevicePackages",
    "PaginationResultExternalPackage",
    "PaginationResultFleet",
    "PaginationResultNetworkInfo",
    "PaginationResultPackage",
    "PaginationResultString",
    "PaginationResultUpdateResponse",
    "PostUpdates400Response",
    "ProvisionInfo",
    "PublicKeys",
    "QueueResponse",
    "RangeNotSatisfiableRepr",
    "Series",
    "SeriesMeta",
    "SignatureMethod",
    "SimpleDeviceInfo",
    "SimpleDeviceNotAffectedInfo",
    "SortDirection",
    "SshSession",
    "TargetImage",
    "TargetItemsSort",
    "TimeAggregation",
    "TimeAggregationMethod",
    "UpdateCreateResult",
    "UpdateFleet",
    "UpdateHibernationStatusRequest",
    "UpdateRequest",
    "UpdateResponse",
    "UpstreamEndpointErrorRepr",
    "UserInfo",
    "UserSession",
]

# import apis into sdk package
from torizon_io_api.api.device_metrics_api import DeviceMetricsApi as DeviceMetricsApi
from torizon_io_api.api.devices_api import DevicesApi as DevicesApi
from torizon_io_api.api.fleets_api import FleetsApi as FleetsApi
from torizon_io_api.api.packages_api import PackagesApi as PackagesApi
from torizon_io_api.api.remote_access_api import RemoteAccessApi as RemoteAccessApi
from torizon_io_api.api.updates_api import UpdatesApi as UpdatesApi

# import ApiClient
from torizon_io_api.api_response import ApiResponse as ApiResponse
from torizon_io_api.api_client import ApiClient as ApiClient
from torizon_io_api.configuration import Configuration as Configuration
from torizon_io_api.exceptions import OpenApiException as OpenApiException
from torizon_io_api.exceptions import ApiTypeError as ApiTypeError
from torizon_io_api.exceptions import ApiValueError as ApiValueError
from torizon_io_api.exceptions import ApiKeyError as ApiKeyError
from torizon_io_api.exceptions import ApiAttributeError as ApiAttributeError
from torizon_io_api.exceptions import ApiException as ApiException

# import models into sdk package
from torizon_io_api.models.bad_request_repr import BadRequestRepr as BadRequestRepr
from torizon_io_api.models.client_signature import ClientSignature as ClientSignature
from torizon_io_api.models.conflict_repr import ConflictRepr as ConflictRepr
from torizon_io_api.models.create_fleet import CreateFleet as CreateFleet
from torizon_io_api.models.create_lockbox_request import CreateLockboxRequest as CreateLockboxRequest
from torizon_io_api.models.create_session_request import CreateSessionRequest as CreateSessionRequest
from torizon_io_api.models.custom_update_data import CustomUpdateData as CustomUpdateData
from torizon_io_api.models.delegation_info import DelegationInfo as DelegationInfo
from torizon_io_api.models.detailed_metric_query import DetailedMetricQuery as DetailedMetricQuery
from torizon_io_api.models.device_create_req import DeviceCreateReq as DeviceCreateReq
from torizon_io_api.models.device_id import DeviceId as DeviceId
from torizon_io_api.models.device_info import DeviceInfo as DeviceInfo
from torizon_io_api.models.device_info_basic import DeviceInfoBasic as DeviceInfoBasic
from torizon_io_api.models.device_info_extended import DeviceInfoExtended as DeviceInfoExtended
from torizon_io_api.models.device_name_request import DeviceNameRequest as DeviceNameRequest
from torizon_io_api.models.device_notes_request import DeviceNotesRequest as DeviceNotesRequest
from torizon_io_api.models.device_packages import DevicePackages as DevicePackages
from torizon_io_api.models.device_session import DeviceSession as DeviceSession
from torizon_io_api.models.device_sort import DeviceSort as DeviceSort
from torizon_io_api.models.device_sort_direction import DeviceSortDirection as DeviceSortDirection
from torizon_io_api.models.device_status import DeviceStatus as DeviceStatus
from torizon_io_api.models.ecu_info_image import EcuInfoImage as EcuInfoImage
from torizon_io_api.models.ecu_info_response import EcuInfoResponse as EcuInfoResponse
from torizon_io_api.models.edit_package import EditPackage as EditPackage
from torizon_io_api.models.error_representation import ErrorRepresentation as ErrorRepresentation
from torizon_io_api.models.external_package import ExternalPackage as ExternalPackage
from torizon_io_api.models.file_info import FileInfo as FileInfo
from torizon_io_api.models.fleet import Fleet as Fleet
from torizon_io_api.models.fleet_metrics_outliers_request import FleetMetricsOutliersRequest as FleetMetricsOutliersRequest
from torizon_io_api.models.fleet_metrics_outliers_response import FleetMetricsOutliersResponse as FleetMetricsOutliersResponse
from torizon_io_api.models.fleet_type import FleetType as FleetType
from torizon_io_api.models.image import Image as Image
from torizon_io_api.models.installed_package import InstalledPackage as InstalledPackage
from torizon_io_api.models.ip_address_request import IpAddressRequest as IpAddressRequest
from torizon_io_api.models.json_signed_payload import JsonSignedPayload as JsonSignedPayload
from torizon_io_api.models.key_data import KeyData as KeyData
from torizon_io_api.models.last_ssh_session import LastSshSession as LastSshSession
from torizon_io_api.models.metrics_response import MetricsResponse as MetricsResponse
from torizon_io_api.models.network_info import NetworkInfo as NetworkInfo
from torizon_io_api.models.not_found_repr import NotFoundRepr as NotFoundRepr
from torizon_io_api.models.outlier import Outlier as Outlier
from torizon_io_api.models.outlier_aggregation_method import OutlierAggregationMethod as OutlierAggregationMethod
from torizon_io_api.models.outlier_values import OutlierValues as OutlierValues
from torizon_io_api.models.package import Package as Package
from torizon_io_api.models.pagination_result_device_info_basic import PaginationResultDeviceInfoBasic as PaginationResultDeviceInfoBasic
from torizon_io_api.models.pagination_result_device_packages import PaginationResultDevicePackages as PaginationResultDevicePackages
from torizon_io_api.models.pagination_result_external_package import PaginationResultExternalPackage as PaginationResultExternalPackage
from torizon_io_api.models.pagination_result_fleet import PaginationResultFleet as PaginationResultFleet
from torizon_io_api.models.pagination_result_network_info import PaginationResultNetworkInfo as PaginationResultNetworkInfo
from torizon_io_api.models.pagination_result_package import PaginationResultPackage as PaginationResultPackage
from torizon_io_api.models.pagination_result_string import PaginationResultString as PaginationResultString
from torizon_io_api.models.pagination_result_update_response import PaginationResultUpdateResponse as PaginationResultUpdateResponse
from torizon_io_api.models.post_updates400_response import PostUpdates400Response as PostUpdates400Response
from torizon_io_api.models.provision_info import ProvisionInfo as ProvisionInfo
from torizon_io_api.models.public_keys import PublicKeys as PublicKeys
from torizon_io_api.models.queue_response import QueueResponse as QueueResponse
from torizon_io_api.models.range_not_satisfiable_repr import RangeNotSatisfiableRepr as RangeNotSatisfiableRepr
from torizon_io_api.models.series import Series as Series
from torizon_io_api.models.series_meta import SeriesMeta as SeriesMeta
from torizon_io_api.models.signature_method import SignatureMethod as SignatureMethod
from torizon_io_api.models.simple_device_info import SimpleDeviceInfo as SimpleDeviceInfo
from torizon_io_api.models.simple_device_not_affected_info import SimpleDeviceNotAffectedInfo as SimpleDeviceNotAffectedInfo
from torizon_io_api.models.sort_direction import SortDirection as SortDirection
from torizon_io_api.models.ssh_session import SshSession as SshSession
from torizon_io_api.models.target_image import TargetImage as TargetImage
from torizon_io_api.models.target_items_sort import TargetItemsSort as TargetItemsSort
from torizon_io_api.models.time_aggregation import TimeAggregation as TimeAggregation
from torizon_io_api.models.time_aggregation_method import TimeAggregationMethod as TimeAggregationMethod
from torizon_io_api.models.update_create_result import UpdateCreateResult as UpdateCreateResult
from torizon_io_api.models.update_fleet import UpdateFleet as UpdateFleet
from torizon_io_api.models.update_hibernation_status_request import UpdateHibernationStatusRequest as UpdateHibernationStatusRequest
from torizon_io_api.models.update_request import UpdateRequest as UpdateRequest
from torizon_io_api.models.update_response import UpdateResponse as UpdateResponse
from torizon_io_api.models.upstream_endpoint_error_repr import UpstreamEndpointErrorRepr as UpstreamEndpointErrorRepr
from torizon_io_api.models.user_info import UserInfo as UserInfo
from torizon_io_api.models.user_session import UserSession as UserSession

